@@ -11,7 +11,7 @@ use WWW::Mechanize::Link;
 use IO::Socket::INET;
 
 use vars qw($VERSION %link_spec @CARP_NOT);
-$VERSION= '0.12';
+$VERSION= '0.13';
 @CARP_NOT=qw(Selenium::Remote::Driver);
 
 =head1 NAME
@@ -515,7 +515,7 @@ JS
 
 =head2 C<< $mech->get( $url, %options ) >>
 
-  $mech->get( $url, ':content_file' => $tempfile );
+  $mech->get( $url  );
 
 Retrieves the URL C<URL>.
 
@@ -524,19 +524,7 @@ with L<WWW::Mechanize>. It seems that Selenium and thus L<Selenium::Remote::Driv
 have no concept of HTTP status code and thus no way of returning the
 HTTP status code.
 
-Recognized options:
-
-=over 4
-
-=item *
-
-C<< :content_file >> - filename to store the data in
-
-=item *
-
-C<< no_cache >> - if true, bypass the browser cache
-
-=back
+Note that PhantomJs does not support download of files.
 
 =cut
 
@@ -575,6 +563,7 @@ sub get {
     # We need to stringify $url so it can pass through JSON
     my $phantom_res= $self->driver->get( "$url" );
     $self->post_process;
+    
     $self->update_response( $phantom_res );
 };
 
@@ -1051,7 +1040,7 @@ sub content_type {
         my $h= $r->headers;
         $ct= $h->header('Content-Type');
     };
-    $ct =~ s/;.*$//;
+    $ct =~ s/;.*$// if defined $ct;
     $ct
 };
 
@@ -2665,7 +2654,7 @@ sub content_as_png {
 
     if( scalar keys %$rect ) {
 
-        $self->viewport_size( $ rect );
+        $self->eval_in_phantomjs( 'this.clipRect= arguments[0]', $rect );
     };
 
     return $self->render_content( format => 'png' );
@@ -2684,11 +2673,10 @@ sub viewport_size {
     my( $self, $new )= @_;
 
     $self->eval_in_phantomjs( <<'JS', $new );
-        var viewportSize= this.clipRect;
         if( arguments[0]) {
-            this.clipRect= arguments[0];
+            this.viewportSize= arguments[0];
         };
-        viewportSize
+        return this.viewportSize;
 JS
 };
 
